@@ -5,7 +5,7 @@ use XSLoader;
 our $VERSION;
 
 BEGIN {
-    $VERSION = '0.00001_03';
+    $VERSION = '0.00001';
     XSLoader::load( __PACKAGE__, $VERSION );
 }
 
@@ -21,11 +21,11 @@ __END__
 
 =head1 NAME
 
-Algorithm::ConsistentHash::Ketama - Ketama Consistent Hashing for Perl (XS)
+Algorithm::ConsitentHash::Ketama - Ketama Consistent Hashing for Perl (XS)
 
 =head1 SYNOPSIS
 
-    use Algorithm::ConsistentHash::Ketama;
+    use Algorithm::ConsitentHash::Ketama;
 
     my $ketama = Algorithm::ConsistentHash::Ketama->new();
 
@@ -73,15 +73,15 @@ Returns a list of Algorithm::ConsistentHash::Ketama::Bucket objects
 Portions of this distribution are derived from libketama, which is:
 
     Copyright (C) 2007 by                                          
-       Christian Muehlhaeuser C<< <chris@last.fm> >>
-       Richard Jones C<< <rj@last.fm> >>
+       Christian Muehlhaeuser c<< <chris@last.fm> >>
+       Richard Jones c<< <rj@last.fm> >>
 
 Affected portions are licensed under GPL v2.
 
 The rest of the code which is written by Daisuke Maki are available under
 Artistic License v2, and is:
 
-    Copyright (C) 2010  Daisuke Maki C<< <daisuke@endeworks.jp> >>
+    Copyright (C) 2010  Daisuke Maki c<< <daisuke@endeworks.jp> >>
 
 Please see the file xs/Ketama.xs for more detail.
 
